@@ -1,19 +1,11 @@
 use strict;
 use warnings;
-
-=head1 NAME
-
-Amce::CNA - a moer tolernat verison of mehtod location
-
-=head1 VERSION
-
-versino 0.064
-
-=cut
+# ABSTRACT: a moer tolernat verison of mehtod location
 
 package Amce::CNA;
-
-our $VERSION = '0.065';
+{
+  $Amce::CNA::VERSION = '0.066';
+}
 
 use Class::ISA;
 
@@ -25,27 +17,6 @@ use Sub::Exporter -setup => {
   groups  => [ default => [ qw(AUTOLOAD can) ] ],
 };
 
-=head1 SYNOPSIS
-
-  package Riddle::Tom;
-  use Amce::CNA;
-
-  sub tom_marvolo_riddle {
-    return "That's me!";
-  }
-
-And then...
-
-  print Riddle::Tom->i_am_lord_voldemort;
-  # => "That's me!"
-
-O NOES!
-
-=head1 DESCRIPTION
-
-This modlue makes it eaiser for dislexics to wriet workign Perl.
-
-=cut
 
 my %methods;
 
@@ -111,6 +82,41 @@ sub AUTOLOAD { ## no critic Autoload
   die sprintf $error_msg, $method, ((ref $_[0])||$_[0]), $callfile, $callline;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Amce::CNA - a moer tolernat verison of mehtod location
+
+=head1 VERSION
+
+version 0.066
+
+=head1 SYNOPSIS
+
+  package Riddle::Tom;
+  use Amce::CNA;
+
+  sub tom_marvolo_riddle {
+    return "That's me!";
+  }
+
+And then...
+
+  print Riddle::Tom->i_am_lord_voldemort;
+  # => "That's me!"
+
+O NOES!
+
+=head1 DESCRIPTION
+
+This modlue makes it eaiser for dislexics to wriet workign Perl.
+
 =head1 TANKHS
 
 Hans Deiter Peercay, for laughing at the joek and rembemering the original
@@ -124,19 +130,26 @@ ueQit ysib.lpos
 
 =over
 
-=item L<Symbol::Approx::Sub>
+=item *
+
+L<Symbol::Approx::Sub>
 
 =back
 
+=head1 LINESCE
+
+This program is free weftsoar;  you cna rdstrbteieiu it aond/r modfiy it ndeur
+the saem terms as rePl etsilf.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 Ricardo SIGNES.  This program is free weftsoar;  you cna
-rdstrbteieiu it aond/r modfiy it ndeur the saem terms as rePl etsilf.
+This software is copyright (c) 2006 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
